/*
 *   IRC - Internet Relay Chat, src/modules/m_rfc.c
 *   (C) 2002-2005 Tiburon <tiburon@betasirc.net>
 *   Copyright (C) 2002-2005 The QuakeIRCd Development Team
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers. 
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#include "proto.h"
#ifdef STRIPBADWORDS
#include "badwords.h"
#endif
#ifdef _WIN32
#include "version.h"
#endif

#define MSG_RFC 	"RFC"
#define TOK_RFC 	"RC"

DLLFUNC int m_rfc(aClient *cptr, aClient *sptr, int parc, char *parv[]);
#ifndef DYNAMIC_LINKING
ModuleHeader m_rfc_Header
#define Mod_Header m_rfc_Header
#else
ModuleHeader Mod_Header
#endif
  = {
	"m_rfc",	/* Name of module */
	"$Id: m_rfc.c,v 1.2 2005/02/24 04:57:17 tirc Exp $", /* Version */
	"/rfc", /* Short description of module */
	"3.2-b8-1",
    };

/*
 * The purpose of these ifdefs, are that we can "static" link the ircd if we
 * want to
*/

#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Init(ModuleInfo *modinfo)
#else
int    m_rfc_Init(ModuleInfo *modinfo)
#endif
{
	/*
	 * We call our add_Command crap here
	*/
	add_Command(MSG_RFC, TOK_RFC, m_rfc, MAXPARA);
	return MOD_SUCCESS;
	
}
#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Load(int module_load)
#else
int    m_rfc_Load(int module_load)
#endif
{
	return MOD_SUCCESS;
	
}
#ifdef DYNAMIC_LINKING
DLLFUNC int	Mod_Unload(int module_unload)
#else
int	m_rfc_Unload(int module_unload)
#endif
{
	if (del_Command(MSG_RFC, TOK_RFC, m_rfc) < 0)
	{
		sendto_realops("Failed to delete commands when unloading %s",
				Mod_Header.name);
	}
	return MOD_SUCCESS;
	
}

/* 
 * m_rfc - 1/29/2005 - Tiburon
 * :prefix RFC
 * parv[0] - sender
 *
*/

DLLFUNC int m_rfc(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
#ifndef PRESERVE_BANDWIDTH
	if (MyClient(sptr))
	{
		sendto_one(sptr, ":%s NOTICE %s : The /rfc command is disabled on this server", me.name, sptr->name);
		return 0;
	}
#endif

#ifdef PRESERVE_BANDWIDTH
	if (!IsPerson(sptr))
		return 0;

	if (!MyClient(sptr) && (IsPerson(sptr)))
        {
                sendto_one(sptr, ":%s NOTICE %s : The /rfc command is a local server command", me.name, sptr->name);
        }

	if (IsRFC(sptr))
	{
		ClearRFC(sptr);	
		sendto_one(sptr, ":%s NOTICE %s : RFC: You are now using the new protocol", me.name, sptr->name);
		return 0;
	}

	if (!IsRFC(sptr))
	{
		SetRFC(sptr);
		sendto_one(sptr, ":%s NOTICE %s : RFC: You are now using the standard protocol", me.name, sptr->name);
		return 0;
	}
#endif
	return 0;
}
